@@ -76,6 +76,7 @@ $post_params = array(
     'MAX_FILE_SIZE',
     'message_to_show',
     'noplugin',
+    'skip',
     'skip_queries',
     'local_import_file'
 );
@@ -643,7 +644,7 @@ if (! empty($id_bookmark) && $_REQUEST['action_bookmark'] == 2) {
         if ($import_notice) {
             $message->addString($import_notice);
         }
-        if (isset($local_import_file)) {
+        if (! empty($local_import_file)) {
             $message->addString('(' . htmlspecialchars($local_import_file) . ')');
         } else {
             $message->addString(
@@ -655,12 +656,19 @@ if (! empty($id_bookmark) && $_REQUEST['action_bookmark'] == 2) {
 
 // Did we hit timeout? Tell it user.
 if ($timeout_passed) {
+    $importUrl = $err_url .= '&timeout_passed=1&offset=' . urlencode($GLOBALS['offset']);
+    if (isset($local_import_file)) {
+        $importUrl .= '&local_import_file=' . urlencode($local_import_file);
+    }
     $message = PMA_Message::error(
         __(
             'Script timeout passed, if you want to finish import,'
-            . ' please resubmit same file and import will resume.'
+            . ' please %sresubmit the same file%s and import will resume.'
         )
     );
+    $message->addParam('<a href="' . $importUrl . '">', false);
+    $message->addParam('</a>', false);
+
     if ($offset == 0 || (isset($original_skip) && $original_skip == $offset)) {
         $message->addString(
             __(
@@ -697,23 +705,37 @@ if (isset($my_die)) {
 
 if ($go_sql) {
 
-    // parse sql query
-    include_once 'libraries/parse_analyze.inc.php';
+    if (! empty($sql_data) && ($sql_data['valid_queries'] > 1)) {
+        $_SESSION['is_multi_query'] = true;
+        $sql_queries = $sql_data['valid_sql'];
+    } else {
+        $sql_queries = array($sql_query);
+    }
 
-    PMA_executeQueryAndSendQueryResponse(
-        $analyzed_sql_results, false, $db, $table, null, $import_text, null,
-        $analyzed_sql_results['is_affected'], null,
-        null, null, $sql_data, $goto, $pmaThemeImage, null, null, null, $sql_query,
-        null, null
-    );
+    $html_output = '';
+    foreach ($sql_queries as $sql_query) {
+        // parse sql query
+        include 'libraries/parse_analyze.inc.php';
+
+        $html_output .= PMA_executeQueryAndGetQueryResponse(
+            $analyzed_sql_results, false, $db, $table, null,
+            $sql_query, null, $analyzed_sql_results['is_affected'],
+            null, null, null, $goto, $pmaThemeImage,
+            null, null, null, $sql_query, null, null
+        );
+    }
 
     if (!isset($ajax_reload)) {
         $ajax_reload = array();
     }
-    $ajax_reload['table_name'] = $table;
-
+    if (isset($table)) {
+        $ajax_reload['table_name'] = $table;
+    }
     $response = PMA_Response::getInstance();
     $response->addJSON('ajax_reload', $ajax_reload);
+    $response->addHTML($html_output);
+    exit();
+
 } else if ($result) {
     // Save a Bookmark with more than one queries (if Bookmark label given).
     if (! empty($_POST['bkm_label']) && ! empty($import_text)) {
