@@ -772,7 +772,7 @@ $(function () {
     /**
      * Attach Ajax event handlers for the Add/Edit functionality.
      */
-    $('a.ajax.add_anchor, a.ajax.edit_anchor').live('click', function (event) {
+    $(document).on('click', 'a.ajax.add_anchor, a.ajax.edit_anchor', function (event) {
         event.preventDefault();
         var type = $(this).attr('href').substr(0, $(this).attr('href').indexOf('?'));
         if (type.indexOf('routine') != -1) {
@@ -786,47 +786,47 @@ $(function () {
         }
         var dialog = new RTE.object(type);
         dialog.editorDialog($(this).hasClass('add_anchor'), $(this));
-    }); // end $.live()
+    }); // end $(document).on()
 
     /**
      * Attach Ajax event handlers for the Execute routine functionality
      */
-    $('a.ajax.exec_anchor').live('click', function (event) {
+    $(document).on('click', 'a.ajax.exec_anchor', function (event) {
         event.preventDefault();
         var dialog = new RTE.object('routine');
         dialog.executeDialog($(this));
-    }); // end $.live()
+    }); // end $(document).on()
 
     /**
      * Attach Ajax event handlers for Export of Routines, Triggers and Events
      */
-    $('a.ajax.export_anchor').live('click', function (event) {
+    $(document).on('click', 'a.ajax.export_anchor', function (event) {
         event.preventDefault();
         var dialog = new RTE.object();
         dialog.exportDialog($(this));
-    }); // end $.live()
+    }); // end $(document).on()
 
     /**
      * Attach Ajax event handlers for Drop functionality
      * of Routines, Triggers and Events.
      */
-    $('a.ajax.drop_anchor').live('click', function (event) {
+    $(document).on('click', 'a.ajax.drop_anchor', function (event) {
         event.preventDefault();
         var dialog = new RTE.object();
         dialog.dropDialog($(this));
-    }); // end $.live()
+    }); // end $(document).on()
 
     /**
      * Attach Ajax event handlers for the "Change event/routine type"
      * functionality in the events editor, so that the correct
      * rows are shown in the editor when changing the event type
      */
-    $('select[name=item_type]').live('change', function () {
+    $(document).on('change', 'select[name=item_type]', function () {
         $(this)
         .closest('table')
         .find('tr.recurring_event_row, tr.onetime_event_row, tr.routine_return_row, .routine_direction_cell')
         .toggle();
-    }); // end $.live()
+    }); // end $(document).on()
 
     /**
      * Attach Ajax event handlers for the "Change parameter type"
@@ -834,7 +834,7 @@ $(function () {
      * option/length fields, if any, are shown when changing
      * a parameter type
      */
-    $('select[name^=item_param_type]').live('change', function () {
+    $(document).on('change', 'select[name^=item_param_type]', function () {
         /**
          * @var row jQuery object containing the reference to
          *          a row in the routine parameters table
@@ -847,14 +847,14 @@ $(function () {
             $row.find('select[name^=item_param_opts_text]'),
             $row.find('select[name^=item_param_opts_num]')
         );
-    }); // end $.live()
+    }); // end $(document).on()
 
     /**
      * Attach Ajax event handlers for the "Change the type of return
      * variable of function" functionality, so that the correct fields,
      * if any, are shown when changing the function return type type
      */
-    $('select[name=item_returntype]').live('change', function () {
+    $(document).on('change', 'select[name=item_returntype]', function () {
         var rte = new RTE.object('routine');
         var $table = $(this).closest('table.rte_table');
         rte.setOptionsForParameter(
@@ -863,12 +863,12 @@ $(function () {
             $table.find('select[name=item_returnopts_text]'),
             $table.find('select[name=item_returnopts_num]')
         );
-    }); // end $.live()
+    }); // end $(document).on()
 
     /**
      * Attach Ajax event handlers for the "Add parameter to routine" functionality
      */
-    $('input[name=routine_addparameter]').live('click', function (event) {
+    $(document).on('click', 'input[name=routine_addparameter]', function (event) {
         event.preventDefault();
         /**
          * @var routine_params_table jQuery object containing the reference
@@ -900,13 +900,13 @@ $(function () {
             $newrow.find('select[name^=item_param_opts_text]'),
             $newrow.find('select[name^=item_param_opts_num]')
         );
-    }); // end $.live()
+    }); // end $(document).on()
 
     /**
      * Attach Ajax event handlers for the
      * "Remove parameter from routine" functionality
      */
-    $('a.routine_param_remove_anchor').live('click', function (event) {
+    $(document).on('click', 'a.routine_param_remove_anchor', function (event) {
         event.preventDefault();
         $(this).parent().parent().remove();
         // After removing a parameter, the indices of the name attributes in
@@ -940,5 +940,5 @@ $(function () {
             });
             index++;
         });
-    }); // end $.live()
+    }); // end $(document).on()
 }); // end of $()
