@@ -159,17 +159,14 @@ function drawChart() {
     });
     try {
         currentChart = PMA_queryChart(chart_data, columnNames, currentSettings);
+        if (currentChart != null) {
+            $('#saveChart').attr('href', currentChart.toImageString());
+        }
     } catch (err) {
         PMA_ajaxShowMessage(err.message, false);
     }
 }
 
-function saveChartAsImage() {
-    if (currentChart !== null) {
-        currentChart.saveAsImage();
-    }
-}
-
 function getSelectedSeries() {
     var val = $('select[name="chartSeries"]').val() || [];
     var ret = [];
@@ -239,7 +236,6 @@ AJAX.registerTeardown('tbl_chart.js', function () {
     $('input[name="xaxis_label"]').unbind('keyup');
     $('input[name="yaxis_label"]').unbind('keyup');
     $('#resizer').unbind('resizestop');
-    $('#saveChart').unbind('click');
 });
 
 AJAX.registerOnload('tbl_chart.js', function () {
@@ -279,7 +275,7 @@ AJAX.registerOnload('tbl_chart.js', function () {
         if (type == 'bar' || type == 'column' || type == 'area') {
             $('span.barStacked').show();
         } else {
-            $('input[name="barStacked"]').attr('checked', false);
+            $('input[name="barStacked"]').prop('checked', false);
             $.extend(true, currentSettings, {stackSeries : false});
             $('span.barStacked').hide();
         }
@@ -292,15 +288,15 @@ AJAX.registerOnload('tbl_chart.js', function () {
         var $valueColumn  = $('select[name="chartValueColumn"]');
         var $chartSeries  = $('select[name="chartSeries"]');
         if ($(this).is(':checked')) {
-            $seriesColumn.attr('disabled', false);
-            $valueColumn.attr('disabled', false);
-            $chartSeries.attr('disabled', true);
+            $seriesColumn.prop('disabled', false);
+            $valueColumn.prop('disabled', false);
+            $chartSeries.prop('disabled', true);
             currentSettings.seriesColumn = parseInt($seriesColumn.val(), 10);
             currentSettings.valueColumn = parseInt($valueColumn.val(), 10);
         } else {
-            $seriesColumn.attr('disabled', true);
-            $valueColumn.attr('disabled', true);
-            $chartSeries.attr('disabled', false);
+            $seriesColumn.prop('disabled', true);
+            $valueColumn.prop('disabled', true);
+            $chartSeries.prop('disabled', false);
             currentSettings.seriesColumn = null;
             currentSettings.valueColumn = null;
         }
@@ -380,10 +376,6 @@ AJAX.registerOnload('tbl_chart.js', function () {
         drawChart();
     });
 
-    $('#saveChart').click(function() {
-        saveChartAsImage();
-    });
-
     onXAxisChange();
     onDataSeriesChange();
 
@@ -394,7 +386,7 @@ AJAX.registerOnload('tbl_chart.js', function () {
  * Ajax Event handler for 'Go' button click
  *
  */
-$("#tblchartform").live('submit', function (event) {
+$(document).on('submit', "#tblchartform", function (event) {
     if (!checkFormElementInRange(this, 'session_max_rows', PMA_messages.strNotValidRowNumber, 1) ||
         !checkFormElementInRange(this, 'pos', PMA_messages.strNotValidRowNumber, 0 - 1)
     ) {
