@@ -26,8 +26,31 @@ $GLOBALS['dummy_queries'] = array(
         'result' => array(array('pma_test@localhost')),
     ),
     array(
-        'query' => 'SELECT COUNT(*) FROM mysql.user',
-        'result' => false,
+        'query' => "SHOW VARIABLES LIKE 'lower_case_table_names'",
+        'result' => array(array('lower_case_table_names', '1'))
+    ),
+    array(
+        'query' => 'SELECT 1 FROM mysql.user LIMIT 1',
+        'result' => array(array('1')),
+    ),
+    array(
+        'query' => "SELECT 1 FROM `INFORMATION_SCHEMA`.`USER_PRIVILEGES`"
+            . " WHERE `PRIVILEGE_TYPE` = 'CREATE USER'"
+            . " AND '''pma_test''@''localhost''' LIKE `GRANTEE` LIMIT 1",
+        'result' => array(array('1')),
+    ),
+    array(
+        'query' => "SELECT 1 FROM (SELECT `GRANTEE`, `IS_GRANTABLE`"
+            . " FROM `INFORMATION_SCHEMA`.`COLUMN_PRIVILEGES`"
+            . " UNION SELECT `GRANTEE`, `IS_GRANTABLE`"
+            . " FROM `INFORMATION_SCHEMA`.`TABLE_PRIVILEGES`"
+            . " UNION SELECT `GRANTEE`, `IS_GRANTABLE`"
+            . " FROM `INFORMATION_SCHEMA`.`SCHEMA_PRIVILEGES`"
+            . " UNION SELECT `GRANTEE`, `IS_GRANTABLE`"
+            . " FROM `INFORMATION_SCHEMA`.`USER_PRIVILEGES`) t"
+            . " WHERE `IS_GRANTABLE` = 'YES'"
+            . " AND '''pma_test''@''localhost''' LIKE `GRANTEE` LIMIT 1",
+        'result' => array(array('1')),
     ),
     array(
         'query' => 'SHOW MASTER LOGS',
@@ -75,7 +98,7 @@ $GLOBALS['dummy_queries'] = array(
         )
     ),
     array(
-        'query' => 'SHOW INNODB STATUS;',
+        'query' => 'SHOW ENGINE INNODB STATUS;',
         'result' => false,
     ),
     array(
@@ -103,7 +126,7 @@ $GLOBALS['dummy_queries'] = array(
         )
     ),
     array(
-        'query' => 'SHOW VARIABLES LIKE \'language\';',
+        'query' => 'SELECT @@lc_messages;',
         'result' => array(),
     ),
     array(
@@ -202,15 +225,21 @@ $GLOBALS['dummy_queries'] = array(
     ),
     array(
         'query' => 'SELECT `column_name`, `mimetype`, `transformation`,'
-            . ' `transformation_options` FROM `pmadb`.`column_info`'
+            . ' `transformation_options`, `input_transformation`,'
+            . ' `input_transformation_options`'
+            . ' FROM `pmadb`.`column_info`'
             . ' WHERE `db_name` = \'pma_test\' AND `table_name` = \'table1\''
             . ' AND ( `mimetype` != \'\' OR `transformation` != \'\''
-            . ' OR `transformation_options` != \'\')',
+            . ' OR `transformation_options` != \'\''
+            . ' OR `input_transformation` != \'\''
+            . ' OR `input_transformation_options` != \'\')',
         'columns' => array(
-            'column_name', 'mimetype', 'transformation', 'transformation_options'
+            'column_name', 'mimetype', 'transformation', 'transformation_options',
+            'input_transformation', 'input_transformation_options'
         ),
         'result' => array(
-            array('o', 'text/plain', 'sql'),
+            array('o', 'text/plain', 'sql', '', 'regex', '/pma/i'),
+            array('col', 't', 'o/p', '', 'i/p', '')
         )
     ),
     array(
@@ -233,7 +262,7 @@ $GLOBALS['dummy_queries'] = array(
             . ' `CHECKSUM` AS `Checksum`, `CREATE_OPTIONS` AS `Create_options`,'
             . ' `TABLE_COMMENT` AS `Comment`'
             . ' FROM `information_schema`.`TABLES` t'
-            . ' WHERE BINARY `TABLE_SCHEMA` IN (\'pma_test\')'
+            . ' WHERE `TABLE_SCHEMA` IN (\'pma_test\')'
             . ' AND t.`TABLE_NAME` = \'table1\' ORDER BY Name ASC',
         'columns' => array(
             'TABLE_CATALOG', 'TABLE_SCHEMA', 'TABLE_NAME', 'TABLE_TYPE', 'ENGINE',
@@ -312,17 +341,16 @@ $GLOBALS['dummy_queries'] = array(
         'query' => 'SELECT `PRIVILEGE_TYPE` FROM `INFORMATION_SCHEMA`.'
             . '`SCHEMA_PRIVILEGES`'
             . ' WHERE GRANTEE=\'\'\'pma_test\'\'@\'\'localhost\'\'\''
-            . ' AND PRIVILEGE_TYPE=\'TRIGGER\' AND \'pma\\\\_test\''
-            . ' REGEXP REPLACE(REPLACE(TABLE_SCHEMA, \'_\', \'.\'), \'%\', \'.*\')',
+            . ' AND PRIVILEGE_TYPE=\'TRIGGER\' AND \'pma_test\''
+            . ' LIKE `TABLE_SCHEMA`',
         'result' => array(),
     ),
     array(
         'query' => 'SELECT `PRIVILEGE_TYPE` FROM `INFORMATION_SCHEMA`.'
             . '`TABLE_PRIVILEGES`'
             . ' WHERE GRANTEE=\'\'\'pma_test\'\'@\'\'localhost\'\'\''
-            . ' AND PRIVILEGE_TYPE=\'TRIGGER\' AND \'pma\\\\_test\''
-            . ' REGEXP REPLACE(REPLACE(TABLE_SCHEMA, \'_\', \'.\'), \'%\', \'.*\')'
-            . ' AND TABLE_NAME=\'table1\'',
+            . ' AND PRIVILEGE_TYPE=\'TRIGGER\' AND \'pma_test\''
+            . ' LIKE `TABLE_SCHEMA` AND TABLE_NAME=\'table1\'',
         'result' => array(),
     ),
     array(
@@ -336,8 +364,8 @@ $GLOBALS['dummy_queries'] = array(
         'query' => 'SELECT `PRIVILEGE_TYPE` FROM `INFORMATION_SCHEMA`.'
             . '`SCHEMA_PRIVILEGES`'
             . ' WHERE GRANTEE=\'\'\'pma_test\'\'@\'\'localhost\'\'\''
-            . ' AND PRIVILEGE_TYPE=\'EVENT\' AND \'pma\\\\_test\''
-            . ' REGEXP REPLACE(REPLACE(TABLE_SCHEMA, \'_\', \'.\'), \'%\', \'.*\')',
+            . ' AND PRIVILEGE_TYPE=\'EVENT\' AND \'pma_test\''
+            . ' LIKE `TABLE_SCHEMA`',
         'result' => array(),
     ),
     array(
@@ -357,7 +385,7 @@ $GLOBALS['dummy_queries'] = array(
             . ' EVENT_OBJECT_TABLE, ACTION_TIMING, ACTION_STATEMENT, '
             . 'EVENT_OBJECT_SCHEMA, EVENT_OBJECT_TABLE, DEFINER'
             . ' FROM information_schema.TRIGGERS'
-            . ' WHERE TRIGGER_SCHEMA= \'pma_test\''
+            . ' WHERE EVENT_OBJECT_SCHEMA= \'pma_test\''
             . ' AND EVENT_OBJECT_TABLE = \'table1\';',
         'result' => array(),
     ),
@@ -405,7 +433,7 @@ $GLOBALS['dummy_queries'] = array(
         'result' => array(),
     ),
     array(
-        'query' => "SELECT tracking_active FROM pma_table_tracking" .
+        'query' => "SELECT tracking_active FROM `pmadb`.`tracking`" .
             " WHERE db_name = 'pma_test_db'" .
             " AND table_name = 'pma_test_table'" .
             " ORDER BY version DESC",
@@ -415,7 +443,7 @@ $GLOBALS['dummy_queries'] = array(
             )
     ),
     array(
-        'query' => "SELECT tracking_active FROM pma_table_tracking" .
+        'query' => "SELECT tracking_active FROM `pmadb`.`tracking`" .
             " WHERE db_name = 'pma_test_db'" .
             " AND table_name = 'pma_test_table2'" .
             " ORDER BY version DESC",
@@ -475,7 +503,27 @@ $GLOBALS['dummy_queries'] = array(
     array(
         'query' => "SHOW GRANTS",
         'result' => array()
-    )
+    ),
+    array(
+        'query' => "SELECT `SCHEMA_NAME` FROM `INFORMATION_SCHEMA`.`SCHEMATA`, "
+            . "(SELECT DB_first_level FROM ( SELECT DISTINCT "
+            . "SUBSTRING_INDEX(SCHEMA_NAME, '_', 1) DB_first_level "
+            . "FROM INFORMATION_SCHEMA.SCHEMATA WHERE TRUE ) t ORDER BY "
+            . "DB_first_level ASC LIMIT 0, 100) t2 WHERE 1 = LOCATE("
+            . "CONCAT(DB_first_level, '_'), CONCAT(SCHEMA_NAME, '_')) "
+            . "ORDER BY SCHEMA_NAME ASC",
+        'result' => array(
+            "test",
+        )
+    ),
+    array(
+        'query' => "SELECT COUNT(*) FROM ( SELECT DISTINCT SUBSTRING_INDEX("
+            . "SCHEMA_NAME, '_', 1) DB_first_level "
+            . "FROM INFORMATION_SCHEMA.SCHEMATA WHERE TRUE ) t",
+        'result' => array(
+            array(1),
+        )
+    ),
 );
 /**
  * Current database.
@@ -524,12 +572,12 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
     /**
      * selects given database
      *
-     * @param string   $dbname name of db to select
-     * @param resource $link   mysql link resource
+     * @param string $dbname name of db to select
+     * @param object $link   mysql link resource
      *
      * @return bool
      */
-    public function selectDb($dbname, $link = null)
+    public function selectDb($dbname, $link)
     {
         $GLOBALS['dummy_db'] = $dbname;
         return true;
@@ -538,24 +586,26 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
     /**
      * runs a query and returns the result
      *
-     * @param string   $query   query to run
-     * @param resource $link    mysql link resource
-     * @param int      $options query options
+     * @param string $query   query to run
+     * @param object $link    mysql link resource
+     * @param int    $options query options
      *
      * @return mixed
      */
     public function realQuery($query, $link = null, $options = 0)
     {
         $query = trim(preg_replace('/  */', ' ', str_replace("\n", ' ', $query)));
-        for ($i = 0; $i < count($GLOBALS['dummy_queries']); $i++) {
-            if ($GLOBALS['dummy_queries'][$i]['query'] == $query) {
-                $GLOBALS['dummy_queries'][$i]['pos'] = 0;
-                if (is_array($GLOBALS['dummy_queries'][$i]['result'])) {
-                    return $i;
-                } else {
-                    return false;
-                }
+        for ($i = 0, $nb = count($GLOBALS['dummy_queries']); $i < $nb; $i++) {
+            if ($GLOBALS['dummy_queries'][$i]['query'] != $query) {
+                continue;
             }
+
+            $GLOBALS['dummy_queries'][$i]['pos'] = 0;
+            if (!is_array($GLOBALS['dummy_queries'][$i]['result'])) {
+                return false;
+            }
+
+            return $i;
         }
         echo "Not supported query: $query\n";
         return false;
@@ -577,7 +627,7 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
     /**
      * returns result data from $result
      *
-     * @param resource $result result  MySQL result
+     * @param object $result result  MySQL result
      *
      * @return array
      */
@@ -595,50 +645,52 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
     /**
      * returns array of rows with associative and numeric keys from $result
      *
-     * @param resource $result result  MySQL result
+     * @param object $result result  MySQL result
      *
      * @return array
      */
     public function fetchArray($result)
     {
         $data = $this->fetchAny($result);
-        if (is_array($data)
-            && isset($GLOBALS['dummy_queries'][$result]['columns'])
+        if (!is_array($data)
+            || !isset($GLOBALS['dummy_queries'][$result]['columns'])
         ) {
-            foreach ($data as $key => $val) {
-                $data[$GLOBALS['dummy_queries'][$result]['columns'][$key]] = $val;
-            }
             return $data;
         }
+
+        foreach ($data as $key => $val) {
+            $data[$GLOBALS['dummy_queries'][$result]['columns'][$key]] = $val;
+        }
         return $data;
     }
 
     /**
      * returns array of rows with associative keys from $result
      *
-     * @param resource $result MySQL result
+     * @param object $result MySQL result
      *
      * @return array
      */
     public function fetchAssoc($result)
     {
         $data = $this->fetchAny($result);
-        if (is_array($data)
-            && isset($GLOBALS['dummy_queries'][$result]['columns'])
+        if (!is_array($data)
+            || !isset($GLOBALS['dummy_queries'][$result]['columns'])
         ) {
-            $ret = array();
-            foreach ($data as $key => $val) {
-                $ret[$GLOBALS['dummy_queries'][$result]['columns'][$key]] = $val;
-            }
-            return $ret;
+            return $data;
         }
-        return $data;
+
+        $ret = array();
+        foreach ($data as $key => $val) {
+            $ret[$GLOBALS['dummy_queries'][$result]['columns'][$key]] = $val;
+        }
+        return $ret;
     }
 
     /**
      * returns array of rows with numeric keys from $result
      *
-     * @param resource $result MySQL result
+     * @param object $result MySQL result
      *
      * @return array
      */
@@ -651,8 +703,8 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
     /**
      * Adjusts the result pointer to an arbitrary row in the result
      *
-     * @param resource $result database result
-     * @param integer  $offset offset to seek
+     * @param object  $result database result
+     * @param integer $offset offset to seek
      *
      * @return bool true on success, false on failure
      */
@@ -668,7 +720,7 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
     /**
      * Frees memory associated with the result
      *
-     * @param resource $result database result
+     * @param object $result database result
      *
      * @return void
      */
@@ -684,7 +736,7 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
      *
      * @return bool false
      */
-    public function moreResults($link = null)
+    public function moreResults($link)
     {
         return false;
     }
@@ -696,7 +748,7 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
      *
      * @return boolean false
      */
-    public function nextResult($link = null)
+    public function nextResult($link)
     {
         return false;
     }
@@ -704,9 +756,11 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
     /**
      * Store the result returned from multi query
      *
+     * @param object $link the connection object
+     *
      * @return mixed false when empty results / result set when not empty
      */
-    public function storeResult()
+    public function storeResult($link)
     {
         return false;
     }
@@ -718,7 +772,7 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
      *
      * @return string type of connection used
      */
-    public function getHostInfo($link = null)
+    public function getHostInfo($link)
     {
         return '';
     }
@@ -730,7 +784,7 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
      *
      * @return integer version of the MySQL protocol used
      */
-    public function getProtoInfo($link = null)
+    public function getProtoInfo($link)
     {
         return -1;
     }
@@ -752,7 +806,7 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
      *
      * @return string|bool $error or false
      */
-    public function getError($link = null)
+    public function getError($link)
     {
         return false;
     }
@@ -760,37 +814,24 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
     /**
      * returns the number of rows returned by last query
      *
-     * @param resource $result MySQL result
+     * @param object $result MySQL result
      *
      * @return string|int
      */
     public function numRows($result)
     {
-        if (!is_bool($result)) {
-            return count($GLOBALS['dummy_queries'][$result]['result']);
-        } else {
+        if (is_bool($result)) {
             return 0;
         }
-    }
 
-    /**
-     * returns last inserted auto_increment id for given $link
-     * or $GLOBALS['userlink']
-     *
-     * @param object $link the connection object
-     *
-     * @return string|int
-     */
-    public function insertId($link = null)
-    {
-        return -1;
+        return count($GLOBALS['dummy_queries'][$result]['result']);
     }
 
     /**
      * returns the number of rows affected by last query
      *
-     * @param resource $link           the mysql object
-     * @param bool     $get_from_cache whether to retrieve from cache
+     * @param object $link           the mysql object
+     * @param bool   $get_from_cache whether to retrieve from cache
      *
      * @return string|int
      */
@@ -814,17 +855,17 @@ class PMA_DBI_Dummy implements PMA_DBI_Extension
     /**
      * return number of fields in given $result
      *
-     * @param resource $result MySQL result
+     * @param object $result MySQL result
      *
      * @return int  field count
      */
     public function numFields($result)
     {
-        if (isset($GLOBALS['dummy_queries'][$result]['columns'])) {
-            return count($GLOBALS['dummy_queries'][$result]['columns']);
-        } else {
+        if (!isset($GLOBALS['dummy_queries'][$result]['columns'])) {
             return 0;
         }
+
+        return count($GLOBALS['dummy_queries'][$result]['columns']);
     }
 
     /**
