@@ -19,7 +19,9 @@ if (! defined('PHPMYADMIN')) {
 function PMA_shutdownDuringExport()
 {
     $a = error_get_last();
-    if ($a != null && strpos($a['message'], "execution time")) {
+    if ($a != null
+        && /*overload*/mb_strpos($a['message'], "execution time")
+    ) {
         //write in partially downloaded file for future reference of user
         print_r($a);
         //set session variable to check if there was error while exporting
@@ -52,10 +54,14 @@ function PMA_gzencodeNeeded()
      * and gz compression was not asked via $cfg['OBGzip']
      * but transparent compression does not apply when saving to server
      */
+    $chromeAndGreaterThan43 = PMA_USR_BROWSER_AGENT == 'CHROME'
+        && PMA_USR_BROWSER_VER >= 43; // see bug #4942
+
     if (@function_exists('gzencode')
         && ((! @ini_get('zlib.output_compression')
         && ! PMA_isGzHandlerEnabled())
-        || $GLOBALS['save_on_server'])
+        || $GLOBALS['save_on_server']
+        || $chromeAndGreaterThan43)
     ) {
         return true;
     } else {
@@ -83,13 +89,14 @@ function PMA_exportOutputHandler($line)
             isset($GLOBALS['xkana']) ? $GLOBALS['xkana'] : ''
         );
     }
+
     // If we have to buffer data, we will perform everything at once at the end
     if ($GLOBALS['buffer_needed']) {
 
         $dump_buffer .= $line;
         if ($GLOBALS['onfly_compression']) {
 
-            $dump_buffer_len += strlen($line);
+            $dump_buffer_len += /*overload*/mb_strlen($line);
 
             if ($dump_buffer_len > $GLOBALS['memory_limit']) {
                 if ($GLOBALS['output_charset_conversion']) {
@@ -108,6 +115,8 @@ function PMA_exportOutputHandler($line)
                 }
                 if ($GLOBALS['save_on_server']) {
                     $write_result = @fwrite($GLOBALS['file_handle'], $dump_buffer);
+                    // Here, use strlen rather than mb_strlen to get the length
+                    // in bytes to compare against the number of bytes written.
                     if ($write_result != strlen($dump_buffer)) {
                         $GLOBALS['message'] = PMA_Message::error(
                             __('Insufficient space to save the file %s.')
@@ -137,9 +146,13 @@ function PMA_exportOutputHandler($line)
                     $line
                 );
             }
-            if ($GLOBALS['save_on_server'] && strlen($line) > 0) {
+            if ($GLOBALS['save_on_server'] && /*overload*/mb_strlen($line) > 0) {
                 $write_result = @fwrite($GLOBALS['file_handle'], $line);
-                if (! $write_result || ($write_result != strlen($line))) {
+                // Here, use strlen rather than mb_strlen to get the length
+                // in bytes to compare against the number of bytes written.
+                if (! $write_result
+                    || $write_result != strlen($line)
+                ) {
                     $GLOBALS['message'] = PMA_Message::error(
                         __('Insufficient space to save the file %s.')
                     );
@@ -200,14 +213,15 @@ function PMA_getMemoryLimitForExport()
 {
     $memory_limit = trim(@ini_get('memory_limit'));
     $memory_limit_num = (int)substr($memory_limit, 0, -1);
+    $lowerLastChar = strtolower(substr($memory_limit, -1));
     // 2 MB as default
     if (empty($memory_limit) || '-1' == $memory_limit) {
         $memory_limit = 2 * 1024 * 1024;
-    } elseif (strtolower(substr($memory_limit, -1)) == 'm') {
+    } elseif ($lowerLastChar == 'm') {
         $memory_limit = $memory_limit_num * 1024 * 1024;
-    } elseif (strtolower(substr($memory_limit, -1)) == 'k') {
+    } elseif ($lowerLastChar == 'k') {
         $memory_limit = $memory_limit_num * 1024;
-    } elseif (strtolower(substr($memory_limit, -1)) == 'g') {
+    } elseif ($lowerLastChar == 'g') {
         $memory_limit = $memory_limit_num * 1024 * 1024 * 1024;
     } else {
         $memory_limit = (int)$memory_limit;
@@ -273,12 +287,14 @@ function PMA_getExportFilenameAndMimetype(
     // Grab basic dump extension and mime type
     // Check if the user already added extension;
     // get the substring where the extension would be if it was included
-    $extension_start_pos = strlen($filename) - strlen(
+    $extension_start_pos = /*overload*/mb_strlen($filename) - /*overload*/mb_strlen(
         $export_plugin->getProperties()->getExtension()
     ) - 1;
-    $user_extension = substr($filename, $extension_start_pos, strlen($filename));
+    $user_extension = /*overload*/mb_substr(
+        $filename, $extension_start_pos, /*overload*/mb_strlen($filename)
+    );
     $required_extension = "." . $export_plugin->getProperties()->getExtension();
-    if (strtolower($user_extension) != $required_extension) {
+    if (/*overload*/mb_strtolower($user_extension) != $required_extension) {
         $filename  .= $required_extension;
     }
     $mime_type  = $export_plugin->getProperties()->getMimeType();
@@ -354,22 +370,23 @@ function PMA_openExportFile($filename, $quick_export)
  */
 function PMA_closeExportFile($file_handle, $dump_buffer, $save_filename)
 {
-    $message = '';
     $write_result = @fwrite($file_handle, $dump_buffer);
     fclose($file_handle);
-    if (strlen($dump_buffer) > 0
-        && (! $write_result || ($write_result != strlen($dump_buffer)))
+    // Here, use strlen rather than mb_strlen to get the length
+    // in bytes to compare against the number of bytes written.
+    if (/*overload*/mb_strlen($dump_buffer) > 0
+        && (! $write_result || $write_result != strlen($dump_buffer))
     ) {
         $message = new PMA_Message(
             __('Insufficient space to save the file %s.'),
             PMA_Message::ERROR,
-            $save_filename
+            array($save_filename)
         );
     } else {
         $message = new PMA_Message(
             __('Dump has been saved to file %s.'),
             PMA_Message::SUCCESS,
-            $save_filename
+            array($save_filename)
         );
     }
     return $message;
@@ -388,7 +405,10 @@ function PMA_compressExport($dump_buffer, $compression, $filename)
 {
     if ($compression == 'zip' && @function_exists('gzcompress')) {
         $zipfile = new ZipFile();
-        $zipfile->addFile($dump_buffer, substr($filename, 0, -4));
+        $zipfile->addFile(
+            $dump_buffer,
+            substr($filename, 0, -4)
+        );
         $dump_buffer = $zipfile->file();
     } elseif ($compression == 'gzip' && PMA_gzencodeNeeded()) {
         // without the optional parameter level because it bugs
@@ -416,11 +436,15 @@ function PMA_getHtmlForDisplayedExportHeader($export_type, $db, $table)
      */
     $back_button = '<p>[ <a href="';
     if ($export_type == 'server') {
-        $back_button .= 'server_export.php?' . PMA_URL_getCommon();
+        $back_button .= 'server_export.php' . PMA_URL_getCommon();
     } elseif ($export_type == 'database') {
-        $back_button .= 'db_export.php?' . PMA_URL_getCommon($db);
+        $back_button .= 'db_export.php' . PMA_URL_getCommon(array('db' => $db));
     } else {
-        $back_button .= 'tbl_export.php?' . PMA_URL_getCommon($db, $table);
+        $back_button .= 'tbl_export.php' . PMA_URL_getCommon(
+            array(
+                'db' => $db, 'table' => $table
+            )
+        );
     }
 
     // Convert the multiple select elements from an array to a string
@@ -433,7 +457,9 @@ function PMA_getHtmlForDisplayedExportHeader($export_type, $db, $table)
     }
 
     foreach ($_REQUEST as $name => $value) {
-        $back_button .= '&amp;' . urlencode($name) . '=' . urlencode($value);
+        if (!is_array($value)) {
+            $back_button .= '&amp;' . urlencode($name) . '=' . urlencode($value);
+        }
     }
     $back_button .= '&amp;repopulate=1">' . __('Back') . '</a> ]</p>';
 
@@ -454,16 +480,18 @@ function PMA_getHtmlForDisplayedExportHeader($export_type, $db, $table)
  * @param string $crlf            end of line character(s)
  * @param string $err_url         the URL in case of error
  * @param string $export_type     the export type
- * @param string $do_relation     whether to export relation info
- * @param string $do_comments     whether to add comments
- * @param string $do_mime         whether to add MIME info
- * @param string $do_dates        whether to add dates
+ * @param bool   $do_relation     whether to export relation info
+ * @param bool   $do_comments     whether to add comments
+ * @param bool   $do_mime         whether to add MIME info
+ * @param bool   $do_dates        whether to add dates
+ * @param array  $aliases         Alias information for db/table/column
  *
  * @return void
  */
 function PMA_exportServer(
     $db_select, $whatStrucOrData, $export_plugin, $crlf, $err_url,
-    $export_type, $do_relation, $do_comments, $do_mime, $do_dates
+    $export_type, $do_relation, $do_comments, $do_mime, $do_dates,
+    $aliases
 ) {
     if (! empty($db_select)) {
         $tmp_select = implode($db_select, '|');
@@ -472,13 +500,13 @@ function PMA_exportServer(
     // Walk over databases
     foreach ($GLOBALS['pma']->databases as $current_db) {
         if (isset($tmp_select)
-            && strpos(' ' . $tmp_select, '|' . $current_db . '|')
+            && /*overload*/mb_strpos(' ' . $tmp_select, '|' . $current_db . '|')
         ) {
             $tables = $GLOBALS['dbi']->getTables($current_db);
             PMA_exportDatabase(
                 $current_db, $tables, $whatStrucOrData, $export_plugin, $crlf,
                 $err_url, $export_type, $do_relation, $do_comments, $do_mime,
-                $do_dates
+                $do_dates, $aliases
             );
         }
     } // end foreach database
@@ -494,29 +522,36 @@ function PMA_exportServer(
  * @param string $crlf            end of line character(s)
  * @param string $err_url         the URL in case of error
  * @param string $export_type     the export type
- * @param string $do_relation     whether to export relation info
- * @param string $do_comments     whether to add comments
- * @param string $do_mime         whether to add MIME info
- * @param string $do_dates        whether to add dates
+ * @param bool   $do_relation     whether to export relation info
+ * @param bool   $do_comments     whether to add comments
+ * @param bool   $do_mime         whether to add MIME info
+ * @param bool   $do_dates        whether to add dates
+ * @param array  $aliases         Alias information for db/table/column
  *
  * @return void
  */
 function PMA_exportDatabase(
     $db, $tables, $whatStrucOrData, $export_plugin, $crlf, $err_url,
-    $export_type, $do_relation, $do_comments, $do_mime, $do_dates
+    $export_type, $do_relation, $do_comments, $do_mime, $do_dates,
+    $aliases
 ) {
-    if (! $export_plugin->exportDBHeader($db)) {
+    $db_alias = !empty($aliases[$db]['alias'])
+        ? $aliases[$db]['alias'] : '';
+    if (! $export_plugin->exportDBHeader($db, $db_alias)) {
         return;
     }
-    if (! $export_plugin->exportDBCreate($db)) {
+    if (! $export_plugin->exportDBCreate($db, $db_alias)) {
         return;
     }
 
     if (method_exists($export_plugin, 'exportRoutines')
-        && strpos($GLOBALS['sql_structure_or_data'], 'structure') !== false
+        && /*overload*/mb_strpos(
+            $GLOBALS['sql_structure_or_data'],
+            'structure'
+        ) !== false
         && isset($GLOBALS['sql_procedure_function'])
     ) {
-        $export_plugin->exportRoutines($db);
+        $export_plugin->exportRoutines($db, $aliases);
     }
 
     $views = array();
@@ -538,9 +573,9 @@ function PMA_exportDatabase(
 
                 if (isset($GLOBALS['sql_create_view'])) {
                     if (! $export_plugin->exportStructure(
-                        $db, $table, $crlf, $err_url,
-                        'stand_in', $export_type,
-                        $do_relation, $do_comments, $do_mime, $do_dates
+                        $db, $table, $crlf, $err_url, 'stand_in',
+                        $export_type, $do_relation, $do_comments,
+                        $do_mime, $do_dates, $aliases
                     )) {
                         break 1;
                     }
@@ -567,9 +602,9 @@ function PMA_exportDatabase(
                 }
 
                 if (! $export_plugin->exportStructure(
-                    $db, $table, $crlf, $err_url,
-                    'create_table', $export_type,
-                    $do_relation, $do_comments, $do_mime, $do_dates
+                    $db, $table, $crlf, $err_url, 'create_table',
+                    $export_type, $do_relation, $do_comments,
+                    $do_mime, $do_dates, $aliases
                 )) {
                     break 1;
                 }
@@ -585,7 +620,7 @@ function PMA_exportDatabase(
             $local_query  = 'SELECT * FROM ' . PMA_Util::backquote($db)
                 . '.' . PMA_Util::backquote($table);
             if (! $export_plugin->exportData(
-                $db, $table, $crlf, $err_url, $local_query
+                $db, $table, $crlf, $err_url, $local_query, $aliases
             )) {
                 break 1;
             }
@@ -596,9 +631,9 @@ function PMA_exportDatabase(
             || $whatStrucOrData == 'structure_and_data')
         ) {
             if (! $export_plugin->exportStructure(
-                $db, $table, $crlf, $err_url,
-                'triggers', $export_type,
-                $do_relation, $do_comments, $do_mime, $do_dates
+                $db, $table, $crlf, $err_url, 'triggers',
+                $export_type, $do_relation, $do_comments,
+                $do_mime, $do_dates, $aliases
             )) {
                 break 1;
             }
@@ -613,9 +648,9 @@ function PMA_exportDatabase(
                 || $whatStrucOrData == 'structure_and_data'
             ) {
                 if (! $export_plugin->exportStructure(
-                    $db, $view, $crlf, $err_url,
-                    'create_view', $export_type,
-                    $do_relation, $do_comments, $do_mime, $do_dates
+                    $db, $view, $crlf, $err_url, 'create_view',
+                    $export_type, $do_relation, $do_comments,
+                    $do_mime, $do_dates, $aliases
                 )) {
                     break 1;
                 }
@@ -624,9 +659,16 @@ function PMA_exportDatabase(
 
     }
 
-    if (! $export_plugin->exportDBFooter($db)) {
+    if (! $export_plugin->exportDBFooter($db, $db_alias)) {
         return;
     }
+
+    if (($GLOBALS['sql_structure_or_data'] == 'structure'
+        || $GLOBALS['sql_structure_or_data'] == 'structure_and_data')
+        && isset($GLOBALS['sql_procedure_function'])
+    ) {
+        $export_plugin->exportEvents($db, $aliases);
+    }
 }
 
 /**
@@ -639,23 +681,26 @@ function PMA_exportDatabase(
  * @param string $crlf            end of line character(s)
  * @param string $err_url         the URL in case of error
  * @param string $export_type     the export type
- * @param string $do_relation     whether to export relation info
- * @param string $do_comments     whether to add comments
- * @param string $do_mime         whether to add MIME info
- * @param string $do_dates        whether to add dates
+ * @param bool   $do_relation     whether to export relation info
+ * @param bool   $do_comments     whether to add comments
+ * @param bool   $do_mime         whether to add MIME info
+ * @param bool   $do_dates        whether to add dates
  * @param string $allrows         whether "dump all rows" was ticked
  * @param string $limit_to        upper limit
  * @param string $limit_from      starting limit
  * @param string $sql_query       query for which exporting is requested
+ * @param array  $aliases         Alias information for db/table/column
  *
  * @return void
  */
 function PMA_exportTable(
     $db, $table, $whatStrucOrData, $export_plugin, $crlf, $err_url,
     $export_type, $do_relation, $do_comments, $do_mime, $do_dates,
-    $allrows, $limit_to, $limit_from, $sql_query
+    $allrows, $limit_to, $limit_from, $sql_query, $aliases
 ) {
-    if (! $export_plugin->exportDBHeader($db)) {
+    $db_alias = !empty($aliases[$db]['alias'])
+        ? $aliases[$db]['alias'] : '';
+    if (! $export_plugin->exportDBHeader($db, $db_alias)) {
         return;
     }
     if (isset($allrows)
@@ -679,9 +724,9 @@ function PMA_exportTable(
 
             if (isset($GLOBALS['sql_create_view'])) {
                 if (! $export_plugin->exportStructure(
-                    $db, $table, $crlf, $err_url,
-                    'create_view', $export_type,
-                    $do_relation, $do_comments, $do_mime, $do_dates
+                    $db, $table, $crlf, $err_url, 'create_view',
+                    $export_type, $do_relation, $do_comments,
+                    $do_mime, $do_dates, $aliases
                 )) {
                     return;
                 }
@@ -690,9 +735,9 @@ function PMA_exportTable(
         } else if (isset($GLOBALS['sql_create_table'])) {
 
             if (! $export_plugin->exportStructure(
-                $db, $table, $crlf, $err_url,
-                'create_table', $export_type,
-                $do_relation, $do_comments, $do_mime, $do_dates
+                $db, $table, $crlf, $err_url, 'create_table',
+                $export_type, $do_relation, $do_comments,
+                $do_mime, $do_dates, $aliases
             )) {
                 return;
             }
@@ -720,7 +765,7 @@ function PMA_exportTable(
                 . '.' . PMA_Util::backquote($table) . $add_query;
         }
         if (! $export_plugin->exportData(
-            $db, $table, $crlf, $err_url, $local_query
+            $db, $table, $crlf, $err_url, $local_query, $aliases
         )) {
             return;
         }
@@ -731,15 +776,94 @@ function PMA_exportTable(
         || $whatStrucOrData == 'structure_and_data')
     ) {
         if (! $export_plugin->exportStructure(
-            $db, $table, $crlf, $err_url,
-            'triggers', $export_type,
-            $do_relation, $do_comments, $do_mime, $do_dates
+            $db, $table, $crlf, $err_url, 'triggers',
+            $export_type, $do_relation, $do_comments,
+            $do_mime, $do_dates, $aliases
         )) {
             return;
         }
     }
-    if (! $export_plugin->exportDBFooter($db)) {
+    if (! $export_plugin->exportDBFooter($db, $db_alias)) {
         return;
     }
 }
+
+/**
+ * Loads correct page after doing export
+ *
+ * @param string $db          the database name
+ * @param string $table       the table name
+ * @param string $export_type Export type
+ *
+ * @return void
+ */
+function PMA_showExportPage($db, $table, $export_type)
+{
+    global $cfg;
+    if ($export_type == 'server') {
+        $active_page = 'server_export.php';
+        include_once 'server_export.php';
+    } elseif ($export_type == 'database') {
+        $active_page = 'db_export.php';
+        include_once 'db_export.php';
+    } else {
+        $active_page = 'tbl_export.php';
+        include_once 'tbl_export.php';
+    }
+    exit();
+}
+
+/**
+ * Merge two alias arrays, if array1 and array2 have
+ * conflicting alias then array2 value is used if it
+ * is non empty otherwise array1 value.
+ *
+ * @param array $aliases1 first array of aliases
+ * @param array $aliases2 second array of aliases
+ *
+ * @return array resultant merged aliases info
+ */
+function PMA_mergeAliases($aliases1, $aliases2)
+{
+    // First do a recursive array merge
+    // on aliases arrays.
+    $aliases = array_merge_recursive($aliases1, $aliases2);
+    // Now, resolve conflicts in aliases, if any
+    foreach ($aliases as $db_name => $db) {
+        // If alias key is an array then
+        // it is a merge conflict.
+        if (isset($db['alias']) && is_array($db['alias'])) {
+            $val1 = $db['alias'][0];
+            $val2 = $db['alias'][1];
+            // Use aliases2 alias if non empty
+            $aliases[$db_name]['alias']
+                = empty($val2) ? $val1 : $val2;
+        }
+        if (!isset($db['tables'])) {
+            continue;
+        }
+        foreach ($db['tables'] as $tbl_name => $tbl) {
+            if (isset($tbl['alias']) && is_array($tbl['alias'])) {
+                $val1 = $tbl['alias'][0];
+                $val2 = $tbl['alias'][1];
+                // Use aliases2 alias if non empty
+                $aliases[$db_name]['tables'][$tbl_name]['alias']
+                    = empty($val2) ? $val1 : $val2;
+            }
+            if (!isset($tbl['columns'])) {
+                continue;
+            }
+            foreach ($tbl['columns'] as  $col => $col_as) {
+                if (isset($col_as) && is_array($col_as)) {
+                    $val1 = $col_as[0];
+                    $val2 = $col_as[1];
+                    // Use aliases2 alias if non empty
+                    $aliases[$db_name]['tables'][$tbl_name]['columns'][$col]
+                        = empty($val2) ? $val1 : $val2;
+                }
+            };
+        };
+    }
+    return $aliases;
+}
 ?>
