@@ -10,6 +10,8 @@ if (! defined('PHPMYADMIN')) {
     exit;
 }
 
+use phpseclib\Crypt;
+
 /* Get the authentication interface */
 require_once 'libraries/plugins/AuthenticationPlugin.class.php';
 
@@ -34,9 +36,12 @@ require './libraries/plugins/auth/swekey/swekey.auth.lib.php';
 if (! function_exists('openssl_encrypt')
     || ! function_exists('openssl_decrypt')
     || ! function_exists('openssl_random_pseudo_bytes')
-    || PHP_VERSION_ID < 50304) {
+    || PHP_VERSION_ID < 50304
+) {
+    require PHPSECLIB_INC_DIR . '/Crypt/Base.php';
+    require PHPSECLIB_INC_DIR . '/Crypt/Rijndael.php';
     require PHPSECLIB_INC_DIR . '/Crypt/AES.php';
-    require PHPSECLIB_INC_DIR . '/Crypt/Random.php';
+    require_once PHPSECLIB_INC_DIR . '/Crypt/Random.php';
 }
 
 /**
@@ -116,7 +121,7 @@ class AuthenticationCookie extends AuthenticationPlugin
         echo '
     <div class="container">
     <a href="';
-        echo PMA_linkURL('http://www.phpmyadmin.net/');
+        echo PMA_linkURL('https://www.phpmyadmin.net/');
         echo '" target="_blank" class="logo">';
         $logo_image = $GLOBALS['pmaThemeImage'] . 'logo_right.png';
         if (@file_exists($logo_image)) {
@@ -218,51 +223,15 @@ class AuthenticationCookie extends AuthenticationPlugin
                 . $GLOBALS['server'] . '" />';
         } // end if (server choice)
 
-        // We already have one correct captcha.
-        $skip = false;
-        if (  isset($_SESSION['last_valid_captcha'])
-            && $_SESSION['last_valid_captcha']
-        ) {
-            $skip = true;
-        }
-
         // Add captcha input field if reCaptcha is enabled
         if (  !empty($GLOBALS['cfg']['CaptchaLoginPrivateKey'])
             && !empty($GLOBALS['cfg']['CaptchaLoginPublicKey'])
-            && !$skip
         ) {
             // If enabled show captcha to the user on the login screen.
-            echo '<script type="text/javascript">
-                    var RecaptchaOptions = {
-                        theme : "white"
-                    };
-                 </script>
-                 <script type="text/javascript"
-                    src="https://www.google.com/recaptcha/api/challenge?'
-                    . 'k=' . $GLOBALS['cfg']['CaptchaLoginPublicKey'] . '&amp;'
-                    . 'hl=' . $GLOBALS['lang'] . '">
-                 </script>
-                 <noscript>
-                    <iframe src="https://www.google.com/recaptcha/api/noscript?k='
-                . $GLOBALS['cfg']['CaptchaLoginPublicKey'] . '"
-                        height="300" width="500" frameborder="0"></iframe><br>
-                    <textarea name="recaptcha_challenge_field" rows="3" cols="40">
-                    </textarea>
-                    <input type="hidden" name="recaptcha_response_field"
-                        value="manual_challenge">
-                 </noscript>
-                 <script type="text/javascript">
-                    $(function() {
-                        $("#recaptcha_reload_btn," +
-                          "#recaptcha_switch_audio_btn," +
-                          "#recaptcha_switch_img_btn," +
-                          "#recaptcha_whatsthis_btn," +
-                          "#recaptcha_audio_play_again")
-                        .live("mouseover", function() {
-                            $(this).addClass("disableAjax");
-                        });
-                    });
-                 </script>';
+            echo '<script src="https://www.google.com/recaptcha/api.js?hl='
+                . $GLOBALS['lang'] . '" async defer></script>';
+            echo '<div class="g-recaptcha" data-sitekey="'
+                . $GLOBALS['cfg']['CaptchaLoginPublicKey'] . '"></div>';
         }
 
         echo '</fieldset>
@@ -349,54 +318,6 @@ class AuthenticationCookie extends AuthenticationPlugin
             return false;
         }
 
-        // We already have one correct captcha.
-        $skip = false;
-        if (  isset($_SESSION['last_valid_captcha'])
-            && $_SESSION['last_valid_captcha']
-        ) {
-            $skip = true;
-        }
-
-        // Verify Captcha if it is required.
-        if (  !empty($GLOBALS['cfg']['CaptchaLoginPrivateKey'])
-            && !empty($GLOBALS['cfg']['CaptchaLoginPublicKey'])
-            && !$skip
-        ) {
-            if (  !empty($_POST["recaptcha_challenge_field"])
-                && !empty($_POST["recaptcha_response_field"])
-            ) {
-                include_once 'libraries/plugins/auth/recaptchalib.php';
-
-                // Use private key to verify captcha status.
-                $resp = recaptcha_check_answer(
-                    $GLOBALS['cfg']['CaptchaLoginPrivateKey'],
-                    $_SERVER["REMOTE_ADDR"],
-                    $_POST["recaptcha_challenge_field"],
-                    $_POST["recaptcha_response_field"]
-                );
-
-                // Check if the captcha entered is valid, if not stop the login.
-                if ( !$resp->is_valid ) {
-                    $conn_error = __('Entered captcha is wrong, try again!');
-                    $_SESSION['last_valid_captcha'] = false;
-                    return false;
-                } else {
-                    $_SESSION['last_valid_captcha'] = true;
-                }
-            } elseif (! empty($_POST["recaptcha_challenge_field"])
-                && empty($_POST["recaptcha_response_field"])
-            ) {
-                $conn_error = __('Please enter correct captcha!');
-                return false;
-            } else {
-                if (! isset($_SESSION['last_valid_captcha'])
-                    || ! $_SESSION['last_valid_captcha']
-                ) {
-                    return false;
-                }
-            }
-        }
-
         if (! empty($_REQUEST['old_usr'])) {
             // The user wants to be logged out
             // -> delete his choices that were stored in session
@@ -406,8 +327,6 @@ class AuthenticationCookie extends AuthenticationPlugin
 
             if (! defined('TESTSUITE')) {
                 session_destroy();
-                // $_SESSION array is not immediately emptied
-                $_SESSION['last_valid_captcha'] = false;
             }
             // -> delete password cookie(s)
             if ($GLOBALS['cfg']['LoginCookieDeleteAll']) {
@@ -428,6 +347,35 @@ class AuthenticationCookie extends AuthenticationPlugin
         }
 
         if (! empty($_REQUEST['pma_username'])) {
+
+            // Verify Captcha if it is required.
+            if (! empty($GLOBALS['cfg']['CaptchaLoginPrivateKey'])
+                && ! empty($GLOBALS['cfg']['CaptchaLoginPublicKey'])
+            ) {
+                if (! empty($_POST["g-recaptcha-response"])) {
+
+                    include_once 'libraries/plugins/auth/recaptcha/autoload.php';
+                    $reCaptcha = new \ReCaptcha\ReCaptcha(
+                        $GLOBALS['cfg']['CaptchaLoginPrivateKey']
+                    );
+
+                    // verify captcha status.
+                    $resp = $reCaptcha->verify(
+                        $_POST["g-recaptcha-response"],
+                        $_SERVER["REMOTE_ADDR"]
+                    );
+
+                    // Check if the captcha entered is valid, if not stop the login.
+                    if ($resp == null || ! $resp->isSuccess()) {
+                        $conn_error = __('Entered captcha is wrong, try again!');
+                        return false;
+                    }
+                } else {
+                    $conn_error = __('Please enter correct captcha!');
+                    return false;
+                }
+            }
+
             // The user just logged in
             $GLOBALS['PHP_AUTH_USER'] = $_REQUEST['pma_username'];
             $GLOBALS['PHP_AUTH_PW']   = empty($_REQUEST['pma_password'])
@@ -436,6 +384,24 @@ class AuthenticationCookie extends AuthenticationPlugin
             if ($GLOBALS['cfg']['AllowArbitraryServer']
                 && isset($_REQUEST['pma_servername'])
             ) {
+                if ($GLOBALS['cfg']['ArbitraryServerRegexp']) {
+                    $parts = explode(' ', $_REQUEST['pma_servername']);
+                    if (count($parts) == 2) {
+                        $tmp_host = $parts[0];
+                    } else {
+                        $tmp_host = $_REQUEST['pma_servername'];
+                    }
+
+                    $match = preg_match(
+                        $GLOBALS['cfg']['ArbitraryServerRegexp'], $tmp_host
+                    );
+                    if (! $match) {
+                        $conn_error = __(
+                            'You are not allowed to log in to this MySQL server!'
+                        );
+                        return false;
+                    }
+                }
                 $GLOBALS['pma_auth_server'] = $_REQUEST['pma_servername'];
             }
             return true;
@@ -454,7 +420,7 @@ class AuthenticationCookie extends AuthenticationPlugin
 
         // check cookies
         if (empty($_COOKIE['pmaUser-' . $GLOBALS['server']])
-            || empty($_COOKIE['pma_iv'])
+            || empty($_COOKIE['pma_iv-' . $GLOBALS['server']])
         ) {
             return false;
         }
@@ -570,7 +536,7 @@ class AuthenticationCookie extends AuthenticationPlugin
     /**
      * Stores user credentials after successful login.
      *
-     * @return void
+     * @return void|bool
      */
     public function storeUserCredentials()
     {
@@ -736,7 +702,7 @@ class AuthenticationCookie extends AuthenticationPlugin
             if ($this->_useOpenSSL()) {
                 $_SESSION['encryption_key'] = openssl_random_pseudo_bytes(256);
             } else {
-                $_SESSION['encryption_key'] = crypt_random_string(256);
+                $_SESSION['encryption_key'] = Crypt\Random::string(256);
             }
         }
         return $_SESSION['encryption_key'];
@@ -777,7 +743,7 @@ class AuthenticationCookie extends AuthenticationPlugin
                 $this->_cookie_iv
             );
         } else {
-            $cipher = new Crypt_AES(CRYPT_AES_MODE_CBC);
+            $cipher = new Crypt\AES(Crypt\Base::MODE_CBC);
             $cipher->setIV($this->_cookie_iv);
             $cipher->setKey($secret);
             return base64_encode($cipher->encrypt($data));
@@ -796,9 +762,9 @@ class AuthenticationCookie extends AuthenticationPlugin
     public function cookieDecrypt($encdata, $secret)
     {
         if (is_null($this->_cookie_iv)) {
-            $this->_cookie_iv = base64_decode($_COOKIE['pma_iv'], true);
+            $this->_cookie_iv = base64_decode($_COOKIE['pma_iv-' . $GLOBALS['server']], true);
         }
-        if (strlen($this->_cookie_iv) < $this->getIVSize()) {
+        if (mb_strlen($this->_cookie_iv,'8bit') < $this->getIVSize()) {
                 $this->createIV();
         }
 
@@ -811,7 +777,7 @@ class AuthenticationCookie extends AuthenticationPlugin
                 $this->_cookie_iv
             );
         } else {
-            $cipher = new Crypt_AES(CRYPT_AES_MODE_CBC);
+            $cipher = new Crypt\AES(Crypt\Base::MODE_CBC);
             $cipher->setIV($this->_cookie_iv);
             $cipher->setKey($secret);
             return $cipher->decrypt(base64_decode($encdata));
@@ -828,7 +794,7 @@ class AuthenticationCookie extends AuthenticationPlugin
         if ($this->_useOpenSSL()) {
             return openssl_cipher_iv_length('AES-128-CBC');
         }
-        $cipher = new Crypt_AES(CRYPT_AES_MODE_CBC);
+        $cipher = new Crypt\AES(Crypt\Base::MODE_CBC);
         return $cipher->block_size;
     }
 
@@ -847,12 +813,12 @@ class AuthenticationCookie extends AuthenticationPlugin
                 $this->getIVSize()
             );
         } else {
-            $this->_cookie_iv = crypt_random_string(
+            $this->_cookie_iv = Crypt\Random::string(
                 $this->getIVSize()
             );
         }
         $GLOBALS['PMA_Config']->setCookie(
-            'pma_iv',
+            'pma_iv-' . $GLOBALS['server'],
             base64_encode($this->_cookie_iv)
         );
     }
@@ -874,11 +840,10 @@ class AuthenticationCookie extends AuthenticationPlugin
      *
      * @param string $password New password to set
      *
-     * @return array Additional URL parameters.
+     * @return void
      */
     public function handlePasswordChange($password)
     {
         $this->storePasswordCookie($password);
-        return array();
     }
 }
