@@ -188,19 +188,6 @@ class ExportLatex extends ExportPlugin
         $this->properties = $exportPluginProperties;
     }
 
-    /**
-     * This method is called when any PluginManager to which the observer
-     * is attached calls PluginManager::notify()
-     *
-     * @param SplSubject $subject The PluginManager notifying the observer
-     *                            of an update.
-     *
-     * @return void
-     */
-    public function update (SplSubject $subject)
-    {
-    }
-
     /**
      * Outputs export header
      *
@@ -240,15 +227,19 @@ class ExportLatex extends ExportPlugin
     /**
      * Outputs database header
      *
-     * @param string $db Database name
+     * @param string $db       Database name
+     * @param string $db_alias Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBHeader ($db)
+    public function exportDBHeader ($db, $db_alias = '')
     {
+        if (empty($db_alias)) {
+            $db_alias = $db;
+        }
         global $crlf;
         $head = '% ' . $crlf
-            . '% ' . __('Database:') . ' ' . '\'' . $db . '\'' . $crlf
+            . '% ' . __('Database:') . ' ' . '\'' . $db_alias . '\'' . $crlf
             . '% ' . $crlf;
         return PMA_exportOutputHandler($head);
     }
@@ -268,11 +259,12 @@ class ExportLatex extends ExportPlugin
     /**
      * Outputs CREATE DATABASE statement
      *
-     * @param string $db Database name
+     * @param string $db       Database name
+     * @param string $db_alias Aliases of db
      *
      * @return bool Whether it succeeded
      */
-    public function exportDBCreate($db)
+    public function exportDBCreate($db, $db_alias = '')
     {
         return true;
     }
@@ -285,22 +277,33 @@ class ExportLatex extends ExportPlugin
      * @param string $crlf      the end of line sequence
      * @param string $error_url the url to go back in case of error
      * @param string $sql_query SQL query for obtaining data
+     * @param array  $aliases   Aliases of db/table/columns
      *
      * @return bool Whether it succeeded
      */
-    public function exportData($db, $table, $crlf, $error_url, $sql_query)
-    {
+    public function exportData(
+        $db, $table, $crlf, $error_url, $sql_query, $aliases = array()
+    ) {
+        $db_alias = $db;
+        $table_alias = $table;
+        $this->initAlias($aliases, $db_alias, $table_alias);
+
         $result      = $GLOBALS['dbi']->tryQuery(
             $sql_query, null, PMA_DatabaseInterface::QUERY_UNBUFFERED
         );
 
         $columns_cnt = $GLOBALS['dbi']->numFields($result);
+        $columns = array();
+        $columns_alias = array();
         for ($i = 0; $i < $columns_cnt; $i++) {
-            $columns[$i] = $GLOBALS['dbi']->fieldName($result, $i);
+            $columns[$i] = $col_as = $GLOBALS['dbi']->fieldName($result, $i);
+            if (!empty($aliases[$db]['tables'][$table]['columns'][$col_as])) {
+                $col_as = $aliases[$db]['tables'][$table]['columns'][$col_as];
+            }
+            $columns_alias[$i] = $col_as;
         }
-        unset($i);
 
-        $buffer = $crlf . '%' . $crlf . '% ' . __('Data:') . ' ' . $table
+        $buffer = $crlf . '%' . $crlf . '% ' . __('Data:') . ' ' . $table_alias
             . $crlf . '%' . $crlf . ' \\begin{longtable}{|';
 
         for ($index = 0; $index < $columns_cnt; $index++) {
@@ -318,13 +321,13 @@ class ExportLatex extends ExportPlugin
                         get_class($this),
                         'libraries/plugins/export/' . get_class($this) . ".class.php"
                     ),
-                    array('table' => $table, 'database' => $db)
+                    array('table' => $table_alias, 'database' => $db_alias)
                 )
                 . '} \\label{'
                 . PMA_Util::expandUserString(
                     $GLOBALS['latex_data_label'],
                     null,
-                    array('table' => $table, 'database' => $db)
+                    array('table' => $table_alias, 'database' => $db_alias)
                 )
                 . '} \\\\';
         }
@@ -337,10 +340,11 @@ class ExportLatex extends ExportPlugin
             $buffer = '\\hline ';
             for ($i = 0; $i < $columns_cnt; $i++) {
                 $buffer .= '\\multicolumn{1}{|c|}{\\textbf{'
-                    . self::texEscape(stripslashes($columns[$i])) . '}} & ';
+                    . self::texEscape(stripslashes($columns_alias[$i])) . '}} & ';
             }
 
-            $buffer = substr($buffer, 0, -2) . '\\\\ \\hline \hline ';
+            $buffer = /*overload*/mb_substr($buffer, 0, -2)
+                . '\\\\ \\hline \hline ';
             if (! PMA_exportOutputHandler($buffer . ' \\endfirsthead ' . $crlf)) {
                 return false;
             }
@@ -355,7 +359,7 @@ class ExportLatex extends ExportPlugin
                             'libraries/plugins/export/'
                             . get_class($this) . ".class.php"
                         ),
-                        array('table' => $table, 'database' => $db)
+                        array('table' => $table_alias, 'database' => $db_alias)
                     )
                     . '} \\\\ '
                 )) {
@@ -428,6 +432,7 @@ class ExportLatex extends ExportPlugin
      *                                export types which use this parameter
      * @param bool   $do_mime     whether to include mime comments
      * @param bool   $dates       whether to include creation/update/check dates
+     * @param array  $aliases     Aliases of db/table/columns
      *
      * @return bool Whether it succeeded
      */
@@ -441,8 +446,13 @@ class ExportLatex extends ExportPlugin
         $do_relation = false,
         $do_comments = false,
         $do_mime = false,
-        $dates = false
+        $dates = false,
+        $aliases = array()
     ) {
+        $db_alias = $db;
+        $table_alias = $table;
+        $this->initAlias($aliases, $db_alias, $table_alias);
+
         global $cfgRelation;
 
         /* We do not export triggers */
@@ -467,41 +477,28 @@ class ExportLatex extends ExportPlugin
         $GLOBALS['dbi']->selectDb($db);
 
         // Check if we can use Relations
-        if ($do_relation && ! empty($cfgRelation['relation'])) {
-            // Find which tables are related with the current one and write it in
-            // an array
-            $res_rel = PMA_getForeigners($db, $table);
-
-            if ($res_rel && count($res_rel) > 0) {
-                $have_rel = true;
-            } else {
-                $have_rel = false;
-            }
-        } else {
-               $have_rel = false;
-        } // end if
-
+        list($res_rel, $have_rel) = PMA_getRelationsAndStatus(
+            $do_relation && ! empty($cfgRelation['relation']),
+            $db,
+            $table
+        );
         /**
          * Displays the table structure
          */
-        $buffer      = $crlf . '%' . $crlf . '% ' . __('Structure:') . ' ' . $table
-            . $crlf . '%' . $crlf . ' \\begin{longtable}{';
+        $buffer      = $crlf . '%' . $crlf . '% ' . __('Structure:') . ' '
+            . $table_alias . $crlf . '%' . $crlf . ' \\begin{longtable}{';
         if (! PMA_exportOutputHandler($buffer)) {
             return false;
         }
 
-        $columns_cnt = 4;
         $alignment = '|l|c|c|c|';
         if ($do_relation && $have_rel) {
-            $columns_cnt++;
             $alignment .= 'l|';
         }
         if ($do_comments) {
-            $columns_cnt++;
             $alignment .= 'l|';
         }
         if ($do_mime && $cfgRelation['mimework']) {
-            $columns_cnt++;
             $alignment .='l|';
         }
         $buffer = $alignment . '} ' . $crlf ;
@@ -533,13 +530,13 @@ class ExportLatex extends ExportPlugin
                         get_class($this),
                         'libraries/plugins/export/' . get_class($this) . ".class.php"
                     ),
-                    array('table' => $table, 'database' => $db)
+                    array('table' => $table_alias, 'database' => $db_alias)
                 )
                 . '} \\label{'
                 . PMA_Util::expandUserString(
                     $GLOBALS['latex_structure_label'],
                     null,
-                    array('table' => $table, 'database' => $db)
+                    array('table' => $table_alias, 'database' => $db_alias)
                 )
                 . '} \\\\' . $crlf;
         }
@@ -555,7 +552,7 @@ class ExportLatex extends ExportPlugin
                         get_class($this),
                         'libraries/plugins/export/' . get_class($this) . ".class.php"
                     ),
-                    array('table' => $table, 'database' => $db)
+                    array('table' => $table_alias, 'database' => $db_alias)
                 )
                 . '} \\\\ ' . $crlf;
         }
@@ -582,19 +579,21 @@ class ExportLatex extends ExportPlugin
                 }
             }
 
-            $field_name = $row['Field'];
+            $field_name = $col_as = $row['Field'];
+            if (!empty($aliases[$db]['tables'][$table]['columns'][$col_as])) {
+                $col_as = $aliases[$db]['tables'][$table]['columns'][$col_as];
+            }
 
-            $local_buffer = $field_name . "\000" . $type . "\000"
+            $local_buffer = $col_as . "\000" . $type . "\000"
                 . (($row['Null'] == '' || $row['Null'] == 'NO')
                     ? __('No') : __('Yes'))
                 . "\000" . (isset($row['Default']) ? $row['Default'] : '');
 
             if ($do_relation && $have_rel) {
                 $local_buffer .= "\000";
-                if (isset($res_rel[$field_name])) {
-                    $local_buffer .= $res_rel[$field_name]['foreign_table'] . ' ('
-                        . $res_rel[$field_name]['foreign_field'] . ')';
-                }
+                $local_buffer .= $this->getRelationString(
+                    $res_rel, $field_name, $db, $aliases
+                );
             }
             if ($do_comments && $cfgRelation['commwork']) {
                 $local_buffer .= "\000";
@@ -614,16 +613,16 @@ class ExportLatex extends ExportPlugin
             }
             $local_buffer = self::texEscape($local_buffer);
             if ($row['Key']=='PRI') {
-                $pos=strpos($local_buffer, "\000");
+                $pos = /*overload*/mb_strpos($local_buffer, "\000");
                 $local_buffer = '\\textit{'
-                    . substr($local_buffer, 0, $pos)
-                    . '}' . substr($local_buffer, $pos);
+                    . /*overload*/mb_substr($local_buffer, 0, $pos)
+                    . '}' . /*overload*/mb_substr($local_buffer, $pos);
             }
             if (in_array($field_name, $unique_keys)) {
-                $pos=strpos($local_buffer, "\000");
+                $pos = /*overload*/mb_strpos($local_buffer, "\000");
                 $local_buffer = '\\textbf{'
-                    . substr($local_buffer, 0, $pos)
-                    . '}' . substr($local_buffer, $pos);
+                    . /*overload*/mb_substr($local_buffer, 0, $pos)
+                    . '}' . /*overload*/mb_substr($local_buffer, $pos);
             }
             $buffer = str_replace("\000", ' & ', $local_buffer);
             $buffer .= ' \\\\ \\hline ' . $crlf;
