@@ -105,6 +105,11 @@ function PMA_RTN_parseOneParameter($value)
                     4 => '');
     $parsed_param = PMA_SQP_parse($value);
     $pos = 0;
+    while ($pos < $parsed_param['len']
+        && $parsed_param[$pos]['type'] == 'white_newline'
+    ) {
+        $pos++;
+    }
     if (in_array(
         /*overload*/mb_strtoupper($parsed_param[$pos]['data']),
         $param_directions
@@ -850,7 +855,7 @@ function PMA_RTN_getParameterRow($routine = array(), $index = null, $class = '')
 /**
  * Displays a form used to add/edit a routine
  *
- * @param string $mode      If the editor will be used edit a routine
+ * @param string $mode      If the editor will be used to edit a routine
  *                          or add a new one: 'edit' or 'add'.
  * @param string $operation If the editor was previously invoked with
  *                          JS turned off, this will hold the name of
@@ -1147,7 +1152,6 @@ function PMA_RTN_getQueryFromRequest()
     }
     $params = '';
     $warned_about_dir    = false;
-    $warned_about_name   = false;
     $warned_about_length = false;
 
     if (   ! empty($_REQUEST['item_param_name'])
@@ -1224,8 +1228,7 @@ function PMA_RTN_getQueryFromRequest()
                 if ($i != (count($item_param_name) - 1)) {
                     $params .= ", ";
                 }
-            } else if (! $warned_about_name) {
-                $warned_about_name = true;
+            } else {
                 $errors[] = __(
                     'You must provide a name and a type for each routine parameter.'
                 );
