@@ -118,7 +118,7 @@ function PMA_getHtmlForSqlQueryForm(
     $html .= '</form>' . "\n";
     // print an empty div, which will be later filled with
     // the sql query results by ajax
-    $html .= '<div id="sqlqueryresults"></div>';
+    $html .= '<div id="sqlqueryresultsouter"></div>';
 
     return $html;
 }
@@ -146,8 +146,6 @@ function PMA_getHtmlForSqlQueryFormInsert(
     $locking = '';
     $height = $GLOBALS['cfg']['TextareaRows'] * 2;
 
-    $table          = '';
-    $db             = '';
     $fields_list    = array();
     if (! /*overload*/mb_strlen($GLOBALS['db'])) {
         // prepare for server related
@@ -176,8 +174,8 @@ function PMA_getHtmlForSqlQueryFormInsert(
             );
         }
     } else {
-        $table  = $GLOBALS['table'];
         $db     = $GLOBALS['db'];
+        $table  = $GLOBALS['table'];
         // Get the list and number of fields
         // we do a try_query here, because we could be in the query window,
         // trying to synchronize and the table has not yet been created
@@ -185,13 +183,13 @@ function PMA_getHtmlForSqlQueryFormInsert(
             $db, $GLOBALS['table'], null, true
         );
 
-        $tmp_db_link = '<a href="' . $GLOBALS['cfg']['DefaultTabDatabase']
-            . PMA_URL_getCommon(array('db' => $db)) . '"';
-        $tmp_db_link .= '>'
-            . htmlspecialchars($db) . '</a>';
+        $tmp_tbl_link = '<a href="' . $GLOBALS['cfg']['DefaultTabTable']
+            . PMA_URL_getCommon(array('db' => $db, 'table' => $table)) . '"';
+        $tmp_tbl_link .= '>' . htmlspecialchars($db)
+            . '.' . htmlspecialchars($table) . '</a>';
         // else use
         // $tmp_db_link = htmlspecialchars($db);
-        $legend = sprintf(__('Run SQL query/queries on database %s'), $tmp_db_link);
+        $legend = sprintf(__('Run SQL query/queries on table %s'), $tmp_tbl_link);
         if (empty($query)) {
             $query = PMA_Util::expandUserString(
                 $GLOBALS['cfg']['DefaultQueryTable'], 'backquote'
@@ -219,6 +217,7 @@ function PMA_getHtmlForSqlQueryFormInsert(
         . $auto_sel . $locking . '>'
         . htmlspecialchars($query)
         . '</textarea>';
+    $html .= '<div id="querymessage"></div>';
     // Add buttons to generate query easily for
     // select all, single select, insert, update and delete
     if (count($fields_list)) {
@@ -235,6 +234,12 @@ function PMA_getHtmlForSqlQueryFormInsert(
     }
     $html .= '<input type="button" value="' . __('Clear') . '" id="clear"'
         . ' class="button sqlbutton" />';
+    if ($GLOBALS['cfg']['CodemirrorEnable']) {
+        $html .= '<input type="button" value="' . __('Format') . '" id="format"'
+            . ' class="button sqlbutton" />';
+    }
+    $html .= '<input type="button" value="' . __('Get auto-saved query') . '" id="saved"'
+        . ' class="button sqlbutton" />';
     $html .= '</div>' . "\n";
 
     if (count($fields_list)) {
