@@ -37,10 +37,9 @@ define('SETUP_CONFIG_FILE', './config/config.inc.php');
 define('SETUP_DIR_WRITABLE', true);
 
 /**
- * Directory where examples reside. Useful when you want to include
- * the examples directory with documentation, eg. /usr/share/doc.
+ * Directory where SQL scripts to create/upgrade configuration storage reside.
  */
-define('EXAMPLES_DIR', './examples/');
+define('SQL_DIR', './sql/');
 
 /**
  * Directory where configuration files are stored.
