@@ -324,10 +324,12 @@ input.button:disabled {
 
 textarea {
     overflow: visible;
+    margin: 6px;
     height: <?php echo ceil($GLOBALS['cfg']['TextareaRows'] * 1.2); ?>em;
 }
 
 textarea.char {
+    margin: 6px;
     height: <?php echo ceil($GLOBALS['cfg']['CharTextareaRows'] * 1.2); ?>em;
 }
 
@@ -529,23 +531,6 @@ fieldset .formelement {
     white-space: nowrap;
 }
 
-@media all and (min-width: 1600px) {
-    fieldset .formelement {
-        clear: none;
-    }
-    #foreign_keys.relationalTable td:first-child + td {
-        width: 25%;
-    }
-    #foreign_keys.relationalTable td:first-child + td select {
-        width: 32%;
-        margin-right: 1%;
-    }
-    #foreign_keys.relationalTable {
-        width: 100%;
-    }
-
-}
-
 /* revert for Gecko */
 fieldset div[class=formelement] {
     white-space: normal;
@@ -579,36 +564,30 @@ table tr.even {
     text-align: <?php echo $left; ?>;
 }
 
-<?php if ($GLOBALS['cfg']['BrowseMarkerEnable']) { ?>
-    /* marked table rows */
-    td.marked,
-    table tr.marked td,
-    table tr.marked th,
-    table tr.marked {
+/* marked table rows */
+td.marked:not(.nomarker),
+table tr.marked:not(.nomarker) td,
+table tr.marked:not(.nomarker) th,
+table tr.marked:not(.nomarker) {
     <?php echo $_SESSION['PMA_Theme']->getCssGradient('ced6df', 'b6c6d7'); ?>
     color: <?php echo $GLOBALS['cfg']['BrowseMarkerColor']; ?>;
-    }
-    <?php
-} ?>
+}
 
-<?php if ($GLOBALS['cfg']['BrowsePointerEnable']) { ?>
-    /* hovered items */
-    .odd:hover,
-    .even:hover,
-    .hover {
+/* hovered items */
+.odd:not(.nopointer):hover,
+.even:not(.nopointer):hover,
+.hover:not(.nopointer) {
     <?php echo $_SESSION['PMA_Theme']->getCssGradient('ced6df', 'b6c6d7'); ?>
     color: <?php echo $GLOBALS['cfg']['BrowsePointerColor']; ?>;
-    }
+}
 
-    /* hovered table rows */
-    table tr.odd:hover th,
-    table tr.even:hover th,
-    table tr.hover th {
+/* hovered table rows */
+table tr.odd:not(.nopointer):hover th,
+table tr.even:not(.nopointer):hover th,
+table tr.hover:not(.nopointer) th {
     <?php echo $_SESSION['PMA_Theme']->getCssGradient('ced6df', 'b6c6d7'); ?>
     color: <?php echo $GLOBALS['cfg']['BrowsePointerColor']; ?>;
-    }
-    <?php
-} ?>
+}
 
 /**
  * marks table rows/cells if the db field is in a where condition
@@ -1084,6 +1063,9 @@ div#dataDisplay select {
 div#dataDisplay th {
     line-height: 2em;
 }
+table#tableFieldsId {
+    width: 100%;
+}
 
 /* Calendar */
 table.calendar {
@@ -1162,7 +1144,7 @@ div#tablestatistics table {
     position: fixed;
     padding: .25em .25em .2em;
     top: 0;
-    z-index: 900;
+    z-index: 99;
     background: #888;
 }
 
@@ -1276,7 +1258,7 @@ div#tablestatistics table {
     float: <?php echo $left; ?>;
 }
 
-#fieldset_user_global_rights legend input {
+#fieldset_user_global_rights>legend input {
     margin-<?php echo $left; ?>: 2em;
 }
 /* end user privileges */
@@ -1295,12 +1277,6 @@ h3#serverstatusqueries span {
     display: inline;
 }
 
-img.sortableIcon {
-    float: <?php echo $right; ?>;
-    background-repeat: no-repeat;
-    margin: 0;
-}
-
 .buttonlinks {
     float: <?php echo $right; ?>;
     white-space: nowrap;
@@ -1451,9 +1427,10 @@ div#queryAnalyzerDialog table.queryNums {
 
 /* server variables */
 #serverVariables {
-    min-width: 30em;
+    table-layout: fixed;
+    width: 100%;
 }
-#serverVariables .var-row > div {
+#serverVariables .var-row > td {
     white-space: nowrap;
     overflow: hidden;
     text-overflow: ellipsis;
@@ -1465,15 +1442,17 @@ div#queryAnalyzerDialog table.queryNums {
     <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'cccccc'); ?>
     font-weight: bold;
 }
-#serverVariables .var-header .var-value {
+#serverVariables .var-header {
     text-align: <?php echo $left; ?>;
 }
 #serverVariables .var-row {
     padding: 0.5em;
     min-height: 18px;
 }
+#serverVariables .var-action {
+    width: 120px;
+}
 #serverVariables .var-name {
-    width: 45%;
     float: <?php echo $left; ?>;
     font-weight: bold;
 }
@@ -1820,7 +1799,7 @@ div.sqlvalidate {
     overflow: auto;
 }
 
-#result_query div.sqlOuter {
+.result_query div.sqlOuter {
     background: <?php echo $GLOBALS['cfg']['BgOne']; ?>;
     padding: 1em;
 }
@@ -2171,6 +2150,7 @@ input#input_import_file {
 #index_frm .index_info input,
 #index_frm .index_info select {
     width: 14em;
+    margin: 0;
     box-sizing: border-box;
     -ms-box-sizing: border-box;
     -moz-box-sizing: border-box;
@@ -2239,10 +2219,6 @@ table#index_columns select {
     border-radius: 2px;
 }
 
-.margin#change_column_dialog {
-    margin: 0 .5em;
-}
-
 /* config forms */
 .config-form ul.tabs {
     margin: 1.1em .2em 0;
@@ -2526,6 +2502,10 @@ fieldset .disabled-field td {
 .toggleButton .container {
     position: absolute;
 }
+.toggleButton .container td {
+    background-image: none;
+    background: none;
+}
 .toggleButton .toggleOn {
     color: #fff;
     padding: 0 1em;
@@ -2636,6 +2616,14 @@ fieldset .disabled-field td {
     overflow: hidden;
 }
 
+.pma_table tbody td span code span {
+    display: inline;
+}
+
+.pma_table th.draggable.right span {
+    margin-<?php echo $right; ?>: 0px;
+}
+
 .pma_table th.draggable span {
     margin-<?php echo $right; ?>: 10px;
 }
@@ -2850,6 +2838,7 @@ fieldset .disabled-field td {
 .cEdit .edit_box {
     overflow: hidden;
     padding: 0;
+    margin: 0;
 }
 
 .cEdit .edit_box_posting {
@@ -2862,11 +2851,6 @@ fieldset .disabled-field td {
     height: 10em;
 }
 
-.cEdit .edit_area_right {
-    position: absolute;
-    right: 0;
-}
-
 .cEdit .goto_link {
     background: #EEE;
     color: #555;
@@ -2939,7 +2923,7 @@ div#page_content form#db_search_form.ajax fieldset {
     margin-top: -0.3em;
 }
 
-div#page_content div#tableslistcontainer, div#page_content div.notice, div#page_content div#result_query {
+div#page_content div#tableslistcontainer, div#page_content div.notice, div#page_content div.result_query {
     margin-top: 1em;
 }
 
@@ -3414,4 +3398,4 @@ th.headerSortUp .sorticon, th.headerSortDown:hover .sorticon {
 th.headerSortDown .sorticon, th.headerSortUp:hover .sorticon {
     background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_asc.png');?>);
 }
-/* end of styles of sortable tables */
\ No newline at end of file
+/* end of styles of sortable tables */
